@@ -1,7 +1,7 @@
 /* Emacs style mode select   -*- C++ -*- 
  *-----------------------------------------------------------------------------
  *
- * $Id: d_main.c,v 1.42 1999/10/17 09:35:15 cphipps Exp $
+ * $Id: d_main.c,v 1.46 2000/03/27 10:33:49 cph Exp $
  *
  *  LxDoom, a Doom port for Linux/Unix
  *  based on BOOM, a modified and improved DOOM engine
@@ -33,7 +33,7 @@
  *-----------------------------------------------------------------------------
  */
 
-static const char rcsid[] = "$Id: d_main.c,v 1.42 1999/10/17 09:35:15 cphipps Exp $";
+static const char rcsid[] = "$Id: d_main.c,v 1.46 2000/03/27 10:33:49 cph Exp $";
 
 #include <unistd.h>
 #include <sys/types.h>
@@ -53,6 +53,7 @@ static const char rcsid[] = "$Id: d_main.c,v 1.42 1999/10/17 09:35:15 cphipps Ex
 #include "m_argv.h"
 #include "m_misc.h"
 #include "m_menu.h"
+#include "i_main.h"
 #include "i_system.h"
 #include "i_sound.h"
 #include "i_video.h"
@@ -116,13 +117,13 @@ char    basesavegame[PATH_MAX+1];  // killough 2/16/98: savegame directory
 //jff 4/19/98 list of standard IWAD names
 const char *const standard_iwads[]=
 {
-  "/doom2f.wad",
-  "/doom2.wad",
-  "/plutonia.wad",
-  "/tnt.wad",
-  "/doom.wad",
-  "/doom1.wad",
-  "/doomu.wad", // CPhipps - alow doomu.wad
+  "doom2f.wad",
+  "doom2.wad",
+  "plutonia.wad",
+  "tnt.wad",
+  "doom.wad",
+  "doom1.wad",
+  "doomu.wad", /* CPhipps - alow doomu.wad */
 };
 static const int nstandard_iwads = sizeof standard_iwads/sizeof*standard_iwads;
 
@@ -145,6 +146,9 @@ int eventhead, eventtail;
 //
 void D_PostEvent(event_t *ev)
 {
+  /* cph - suppress all input events at game start
+   * FIXME: This is a lousy kludge */
+  if (gametic < 3) return; 
   events[eventhead++] = *ev;
   eventhead &= MAXEVENTS-1;
 }
@@ -415,70 +419,118 @@ void D_AdvanceDemo (void)
   advancedemo = true;
 }
 
-//
-// This cycles through the demo sequences.
-// FIXME - version dependend demo numbers?
-//
-void D_DoAdvanceDemo (void)
+/* killough 11/98: functions to perform demo sequences 
+ * cphipps 10/99: constness fixes
+ */
+
+static void D_SetPageName(const char *name)
 {
-  players[consoleplayer].playerstate = PST_LIVE;  // not reborn
-  advancedemo = false;
-  usergame = false;               // no save / end game here
-  paused = false;
+  pagename = name;
+}
+
+static void D_DrawTitle1(const char *name)
+{
+  S_StartMusic(mus_intro);
+  pagetic = (TICRATE*170)/35;
+  D_SetPageName(name);
+}
+
+static void D_DrawTitle2(const char *name)
+{
+  S_StartMusic(mus_dm2ttl);
+  D_SetPageName(name);
+}
+
+/* killough 11/98: tabulate demo sequences 
+ */
+
+static struct 
+{
+  void (*func)(const char *);
+  const char *name;
+} const demostates[][4] =
+  {
+    {
+      {D_DrawTitle1, "TITLEPIC"},
+      {D_DrawTitle1, "TITLEPIC"},
+      {D_DrawTitle2, "TITLEPIC"},
+      {D_DrawTitle1, "TITLEPIC"},
+    },
+
+    {
+      {G_DeferedPlayDemo, "demo1"},
+      {G_DeferedPlayDemo, "demo1"},
+      {G_DeferedPlayDemo, "demo1"},
+      {G_DeferedPlayDemo, "demo1"},
+    },
+    {
+      {D_SetPageName, "CREDIT"},
+      {D_SetPageName, "CREDIT"},
+      {D_SetPageName, "CREDIT"},
+      {D_SetPageName, "CREDIT"},
+    },
+
+    {
+      {G_DeferedPlayDemo, "demo2"},
+      {G_DeferedPlayDemo, "demo2"},
+      {G_DeferedPlayDemo, "demo2"},
+      {G_DeferedPlayDemo, "demo2"},
+    },
+
+    {
+      {D_SetPageName, "HELP2"},
+      {D_SetPageName, "HELP2"},
+      {D_SetPageName, "CREDIT"},
+      {D_DrawTitle1,  "TITLEPIC"},
+    },
+
+    {
+      {G_DeferedPlayDemo, "demo3"},
+      {G_DeferedPlayDemo, "demo3"},
+      {G_DeferedPlayDemo, "demo3"},
+      {G_DeferedPlayDemo, "demo3"},
+    },
+
+    {
+      {NULL},
+      {NULL},
+      {NULL},
+      {D_SetPageName, "CREDIT"},
+    },
+
+    {
+      {NULL},
+      {NULL},
+      {NULL},
+      {G_DeferedPlayDemo, "demo4"},
+    },
+
+    {
+      {NULL},
+      {NULL},
+      {NULL},
+      {NULL},
+    }
+  };
+
+/*
+ * This cycles through the demo sequences.
+ * killough 11/98: made table-driven
+ */
+
+void D_DoAdvanceDemo(void)
+{
+  players[consoleplayer].playerstate = PST_LIVE;  /* not reborn */
+  advancedemo = usergame = paused = false;
   gameaction = ga_nothing;
 
-  if ( gamemode == retail )
-    demosequence = (demosequence+1)%7;
-  else
-    demosequence = (demosequence+1)%6;
+  pagetic = TICRATE * 11;         /* killough 11/98: default behavior */
+  gamestate = GS_DEMOSCREEN;
 
-    switch (demosequence)
-      {
-      case 0:
-        if ( gamemode == commercial )
-          pagetic = TICRATE * 11;        // killough 2/22/98: use TICRATE
-        else
-          pagetic = (TICRATE*170)/35;    // killough 2/22/98: use TICRATE
-        gamestate = GS_DEMOSCREEN;
-        pagename = "TITLEPIC";
-        if ( gamemode == commercial )
-          S_StartMusic(mus_dm2ttl);
-        else
-          S_StartMusic(mus_intro);
-        break;
-      case 1:
-        G_DeferedPlayDemo("demo1");
-        break;
-      case 2:
-        pagetic = (TICRATE * 200)/35;    // killough 2/22/98: use TICRATE
-        gamestate = GS_DEMOSCREEN;
-        pagename = "CREDIT";
-        break;
-      case 3:
-        G_DeferedPlayDemo("demo2");
-        break;
-      case 4:
-        gamestate = GS_DEMOSCREEN;
-        if (gamemode == commercial)
-          {
-            pagetic = TICRATE * 11;
-            pagename = "TITLEPIC";
-            S_StartMusic(mus_dm2ttl);
-          }
-        else
-          {
-            pagetic = (TICRATE*200)/35;   // killough 2/22/98: use TICRATE
-            pagename = gamemode == retail ? "CREDIT" : "HELP2";
-          }
-        break;
-      case 5:
-        G_DeferedPlayDemo ("demo3");
-        break;
-        // THE DEFINITIVE DOOM Special Edition demo
-      case 6:
-        G_DeferedPlayDemo ("demo4");
-        break;
-      }
+  if (!demostates[++demosequence][gamemode].func)
+    demosequence = 0;
+  demostates[demosequence][gamemode].func
+    (demostates[demosequence][gamemode].name);
 }
 
 //
@@ -522,7 +574,7 @@ char *D_DoomExeDir(void)
       char *home = getenv("HOME");
       size_t len = strlen(home);
 
-      base = malloc(len + strlen(lxdoom_dir));
+      base = malloc(len + strlen(lxdoom_dir) + 1);
       strcpy(base, home);
       // I've had trouble with trailing slashes before...
       if (base[len-1] == '/') base[len-1] = 0;
@@ -557,8 +609,6 @@ static const char *D_dehout(void)
 // CPhipps - const char* for iwadname, made static
 static void CheckIWAD(const char *iwadname,GameMode_t *gmode,boolean *hassec)
 {
-  char temp[320]; // buffer for error messages
-
   if ( !access (iwadname,R_OK) )
   {
     int ud=0,rg=0,sw=0,cm=0,sc=0;
@@ -615,16 +665,10 @@ static void CheckIWAD(const char *iwadname,GameMode_t *gmode,boolean *hassec)
         free(fileinfo);
       }
       else // missing IWAD tag in header
-      {
-        sprintf(temp,"IWAD tag not present: %s\n",iwadname);
-        I_Error(temp);
-      }
+        I_Error("IWAD tag not present: %s\n",iwadname);
     }
     else // error from open call
-    {
-      sprintf(temp,"Can't open IWAD: %s\n",iwadname);
-      I_Error(temp);
-    }
+      I_Error("Can't open IWAD: %s\n",iwadname);
 
     // Determine game mode from levels present
     // Must be a full set for whichever mode is present
@@ -645,10 +689,7 @@ static void CheckIWAD(const char *iwadname,GameMode_t *gmode,boolean *hassec)
       *gmode = shareware;
   }
   else // error from access call
-  {
-    sprintf(temp,"IWAD not readable: %s\n",iwadname);
-    I_Error(temp);
-  }
+    I_Error("IWAD not readable: %s\n",iwadname);
 }
 
 //
@@ -675,6 +716,17 @@ void NormalizeSlashes(char *str)
       str[l]='/';
 }
 
+/* 
+ * HasTrailingSlash
+ *
+ * cphipps - simple test for trailing slash on dir names
+ */
+
+static boolean HasTrailingSlash(const char* dn)
+{
+  return (dn[strlen(dn)-1] == '/');
+}
+
 // jff 4/19/98 Add routine to check a pathname for existence as
 // a file or directory. If neither append .wad and check if it
 // exists as a file then. Else return non-existent.
@@ -710,240 +762,90 @@ boolean WadFileStatus(char *filename,boolean *isdir)
   return false;                   //and report doesn't exist
 }
 
-//
-// FindIWADFIle
-//
-// Search in all the usual places until an IWAD is found.
-//
-// The global baseiwad contains either a full IWAD file specification
-// or a directory to look for an IWAD in, or the name of the IWAD desired.
-//
-// The global standard_iwads lists the standard IWAD names
-//
-// The result of search is returned in baseiwad, or set blank if none found
-//
-// IWAD search algorithm:
-//
-// Set customiwad blank
-// If -iwad present set baseiwad to normalized path from -iwad parameter
-//  If baseiwad is an existing file, thats it
-//  If baseiwad is an existing dir, try appending all standard iwads
-//  If haven't found it, and no : or / is in baseiwad,
-//   append .wad if missing and set customiwad to baseiwad
-//
-// Look in . for customiwad if set, else all standard iwads
-//
-// Look in DoomExeDir. for customiwad if set, else all standard iwads
-//
-// If $DOOMWADDIR is an existing file
-//  If customiwad is not set, thats it
-//  else replace filename with customiwad, if exists thats it
-// If $DOOMWADDIR is existing dir, try customiwad if set, else standard iwads
-//
-// If $HOME is an existing file
-//  If customiwad is not set, thats it
-//  else replace filename with customiwad, if exists thats it
-// If $HOME is an existing dir, try customiwad if set, else standard iwads
-//
-// IWAD not found
-//
-// jff 4/19/98 Add routine to search for a standard or custom IWAD in one
-// of the standard places. Returns a blank string if not found.
-// CPhipps - static, proper prototype
+/* 
+ * FindWADFile
+ *
+ * cphipps 19/1999 - writen to unify the logic in FindIWADFile and the WAD 
+ * 			autoloading code.
+ * Searches the standard dirs for a named WAD file
+ * The dirs are: 
+ * . 
+ * DOOMWADDIR 
+ * ~/doom 
+ * /usr/share/games/doom 
+ * /usr/local/share/games/doom
+ * ~
+ */
+
+static char* FindWADFile(const char* wfname, const char* ext)
+{
+  int		i;
+  /* Precalculate a length we will need in the loop */
+  size_t	pl = strlen(wfname) + strlen(ext) + 4;
+
+  for (i=0; i<6; i++) {
+    char	*	p;
+    const char	*	d = NULL;
+    const char	*	s = NULL;
+    /* Each entry in the switch sets d to the directory to look in, 
+     * and optionally s to a subdirectory of d */
+    switch(i) {
+    case 1:
+      if (!(d = getenv("DOOMWADDIR"))) continue;
+    case 0:
+      break;
+    case 3:
+      d = "/usr/share/games/doom";
+      break;
+    case 4:
+      d = "/usr/local/share/games/doom";
+      break;
+    case 2:
+      s = "doom";
+    case 5:
+      if (!(d = getenv("HOME"))) continue;
+      break;
+#ifdef SIMPLECHECKS
+    default:
+      I_Error("FindWADFile: internal failure");
+#endif
+    }
+
+    p = malloc((d ? strlen(d) : 0) + (s ? strlen(s) : 0) + pl);
+    sprintf(p, "%s%s%s%s%s", d ? d : "", (d && !HasTrailingSlash(d)) ? "/" : "",
+                             s ? s : "", (s && !HasTrailingSlash(s)) ? "/" : "",
+                             wfname);
+
+    if (access(p,F_OK))
+      strcat(p, ext);
+    if (!access(p,F_OK)) {
+      lprintf(LO_INFO, " found %s\n", p);
+      return p;
+    }
+    free(p);
+  }
+  return NULL;
+}
+
+/*
+ * FindIWADFIle
+ *
+ * Search for one of the standard IWADs
+ * CPhipps	- static, proper prototype
+ *		- 12/1999 - rewritten to use FindWADFile
+ */
 static char *FindIWADFile(void)
 {
-  static char iwad[256];
-  static char customiwad[256];
-  boolean     isdir=false;
-  int         i;
-  const char *p; // cph - const
+  int		i;
+  char	*	iwad	= NULL;
 
-  *iwad = 0;       // default return filename to empty
-  *customiwad = 0; // customiwad is blank
-
-  i = M_CheckParm("-iwad"); //jff 3/24/98 get -iwad parm if specified else use .
-  if (i && i<myargc-1)
-  {
-    sprintf(baseiwad,"%s",myargv[i+1]);
-    NormalizeSlashes(baseiwad);
-
-    strcpy(iwad,baseiwad);
-    if (WadFileStatus(iwad,&isdir))
-    {
-      if (!isdir)
-        return iwad;
-      else
-      {
-        for (i=0;i<nstandard_iwads;i++)
-        {
-          int n = strlen(iwad);
-          strcat(iwad,standard_iwads[i]);
-          if (WadFileStatus(iwad,&isdir) && !isdir)
-            return iwad;
-          iwad[n] = 0; // reset iwad length to former
-        }
-      }
-    }
-    else
-    {
-      if (!strchr(iwad,':') && !strchr(iwad,'/'))
-        AddDefaultExtension(strcat(strcpy(customiwad, "/"), iwad), ".wad");
-    }
+  i = M_CheckParm("-iwad");
+  if (i && (++i < myargc)) {
+    iwad =FindWADFile(myargv[i], ".wad");
+  } else {
+    for (i=0; !iwad && i<nstandard_iwads; i++)
+      iwad = FindWADFile(standard_iwads[i], ".wad");
   }
-
-  // CPhipps - use same DOOMWADDIR env. variable as DeuTex
-  if ((p = getenv("DOOMWADDIR"))) {
-    strcpy(iwad,p);
-    NormalizeSlashes(iwad);
-    if (WadFileStatus(iwad,&isdir))
-    {
-      if (!isdir)
-      {
-        if (!*customiwad)
-        {
-          //jff 9/3/98 use logical output routine
-          lprintf(LO_INFO,"Looking for %s\n",iwad);
-          return iwad;
-        }
-        else
-        {
-          char *p = strrchr(iwad,'/');
-          if (p)
-          {
-            *p=0;
-            strcat(iwad,customiwad);
-            //jff 9/3/98 use logical output routine
-            lprintf(LO_INFO,"Looking for %s\n",iwad);
-            if (WadFileStatus(iwad,&isdir) && !isdir)
-              return iwad;
-          }
-        }
-      }
-      else
-      {
-        //jff 9/3/98 use logical output routine
-        lprintf(LO_INFO,"Looking in %s\n",iwad);
-        if (*customiwad)
-        {
-          strcat(iwad,customiwad);
-          if (WadFileStatus(iwad,&isdir) && !isdir)
-            return iwad;
-        }
-        else
-        {
-          for (i=0;i<nstandard_iwads;i++)
-          {
-            int n = strlen(iwad);
-            strcat(iwad,standard_iwads[i]);
-            if (WadFileStatus(iwad,&isdir) && !isdir)
-              return iwad;
-            iwad[n] = 0; // reset iwad length to former
-          }
-        }
-      }
-    }
-  }
-
-  // CPhipps - use wad dir formed during configuration
-  strcpy(iwad,DOOMWADDIR);
-  //jff 9/3/98 use logical output routine
-  lprintf(LO_INFO,"Looking in %s\n",iwad);
-  if (*customiwad)
-  {
-    strcat(iwad,customiwad);
-    if (WadFileStatus(iwad,&isdir) && !isdir)
-      return iwad;
-  }
-  else
-  {
-    for (i=0;i<nstandard_iwads;i++)
-    {
-      int n = strlen(iwad);
-      strcat(iwad,standard_iwads[i]);
-      if (WadFileStatus(iwad,&isdir) && !isdir)
-        return iwad;
-      iwad[n] = 0; // reset iwad length to former
-    }
-  }
-
-  strcpy(iwad,D_DoomExeDir());
-  NormalizeSlashes(iwad);
-  //jff 9/3/98 use logical output routine
-  lprintf(LO_INFO,"Looking in %s\n",iwad);
-  if (*customiwad)
-  {
-    strcat(iwad,customiwad);
-    if (WadFileStatus(iwad,&isdir) && !isdir)
-      return iwad;
-  }
-  else
-  {
-    for (i=0;i<nstandard_iwads;i++)
-    {
-      int n = strlen(iwad);
-      strcat(iwad,standard_iwads[i]);
-      if (WadFileStatus(iwad,&isdir) && !isdir)
-        return iwad;
-      iwad[n] = 0; // reset iwad length to former
-    }
-  }
-
-  if ((p = getenv("HOME")))
-  {
-    strcpy(iwad,p);
-    NormalizeSlashes(iwad);
-    //jff 9/3/98 use logical output routine
-    lprintf(LO_INFO,"Looking in %s\n",iwad);
-    if (WadFileStatus(iwad,&isdir))
-    {
-      if (!isdir)
-      {
-        if (!*customiwad)
-        {
-          //jff 9/3/98 use logical output routine
-          lprintf(LO_INFO,"Looking for %s\n",iwad);
-          return iwad;
-        }
-        else
-        {
-          char *p = strrchr(iwad,'/');
-          if (p)
-          {
-            *p=0;
-            strcat(iwad,customiwad);
-            //jff 9/3/98 use logical output routine
-            lprintf(LO_INFO,"Looking for %s\n",iwad);
-            if (WadFileStatus(iwad,&isdir) && !isdir)
-              return iwad;
-          }
-        }
-      }
-      else
-      {
-        //jff 9/3/98 use logical output routine
-        lprintf(LO_INFO,"Looking in %s\n",iwad);
-        if (*customiwad)
-        {
-          strcat(iwad,customiwad);
-          if (WadFileStatus(iwad,&isdir) && !isdir)
-            return iwad;
-        }
-        else
-        {
-          for (i=0;i<nstandard_iwads;i++)
-          {
-            int n = strlen(iwad);
-            strcat(iwad,standard_iwads[i]);
-            if (WadFileStatus(iwad,&isdir) && !isdir)
-              return iwad;
-            iwad[n] = 0; // reset iwad length to former
-          }
-        }
-      }
-    }
-  }
-
-  *iwad = 0;
   return iwad;
 }
 
@@ -1012,48 +914,25 @@ void IdentifyVersion (void)
     lprintf(LO_CONFIRM,"IWAD found: %s\n",iwad); //jff 4/20/98 print only if found
     CheckIWAD(iwad,&gamemode,&haswolflevels);
 
-    //jff 8/23/98 set gamemission global appropriately in all cases
+    /* jff 8/23/98 set gamemission global appropriately in all cases
+     * cphipps 12/1999 - no version output here, leave that to the caller 
+     */
     switch(gamemode)
     {
       case retail:
-        //jff 9/3/98 use logical output routine
-        lprintf(LO_CONFIRM,"Ultimate DOOM version\n");
-        gamemission = doom;
-        break;
       case registered:
-        //jff 9/3/98 use logical output routine
-        lprintf(LO_CONFIRM,"DOOM Registered version\n");
-        gamemission = doom;
-        break;
       case shareware:
-        //jff 9/3/98 use logical output routine
-        lprintf(LO_CONFIRM,"DOOM Shareware version\n");
         gamemission = doom;
         break;
       case commercial:
         i = strlen(iwad);
         gamemission = doom2;
         if (i>=10 && !strnicmp(iwad+i-10,"doom2f.wad",10))
-        {
           language=french;
-          //jff 9/3/98 use logical output routine
-          lprintf(LO_CONFIRM,"DOOM II version, french language\n");
-        } 
         else if (i>=7 && !strnicmp(iwad+i-7,"tnt.wad",7))
-        {
           gamemission = pack_tnt;
-          //jff 9/3/98 use logical output routine
-          lprintf(LO_CONFIRM,"TNT version\n");
-        }
         else if (i>=12 && !strnicmp(iwad+i-12,"plutonia.wad",12))
-        {
           gamemission = pack_plut;
-          //jff 9/3/98 use logical output routine
-          lprintf(LO_CONFIRM,"PLUTONIA version\n");
-        }
-        else
-          //jff 9/3/98 use logical output routine
-          lprintf(LO_CONFIRM,"DOOM II version%s\n",haswolflevels? "" : ", german edition, no wolf levels");
         break;
       default:
         gamemission = none;
@@ -1063,6 +942,7 @@ void IdentifyVersion (void)
       //jff 9/3/98 use logical output routine
       lprintf(LO_WARN,"Unknown Game Version, may not work\n");
     D_AddFile(iwad,source_iwad);
+    free(iwad);
   }
   else
     I_Error("IWAD not found\n");
@@ -1366,13 +1246,13 @@ void D_DoomMainSetup(void)
 
     switch ( gamemode ) {
     case retail:
-      doomverstr = "The Ultimate DOOM Startup";
+      doomverstr = "The Ultimate DOOM";
       break;
     case shareware:
-      doomverstr = "DOOM Shareware Startup";
+      doomverstr = "DOOM Shareware";
       break;
     case registered:
-      doomverstr = "DOOM Registered Startup";
+      doomverstr = "DOOM Registered";
       break;
     case commercial:  // Ty 08/27/98 - fixed gamemode vs gamemission
       switch (gamemission)
@@ -1394,7 +1274,7 @@ void D_DoomMainSetup(void)
     }
 
     /* cphipps - the main display. This shows the build date, copyright, and game type */
-    lprintf(LO_ALWAYS,"LxDoom (built %s), playing:%s\n"
+    lprintf(LO_ALWAYS,"LxDoom (built %s), playing: %s\n"
 	    "LxDoom is released under the GNU General Public license v2.0.\n"
 	    "You are welcome to redistribute it under certain conditions.\n"
 	    "It comes with ABSOLUTELY NO WARRANTY. See the file COPYING for details.\n",
@@ -1554,7 +1434,8 @@ void D_DoomMainSetup(void)
     const char* p = auto_load_wads;
 
     while (*p) {
-      char* fname;
+      char	*	fname;
+      char	*	fpath;
       {
 	const char* q;
 	int len;
@@ -1569,52 +1450,22 @@ void D_DoomMainSetup(void)
 	p+=len; if (*p) p++;
       }
       // Filename is now stored as a zero terminated string
-      {
-	int i;
-	
-	for (i=0; i<3; i++) {
-	  const char* folder;
-	  char* path_buf;
-	  
-	  switch(i) {
-	  case 1:
-	    if (!(folder = getenv("DOOMWADDIR"))) 
-	      folder = DOOMWADDIR;
-	    break;
-	  case 2:
-	    folder = getenv("HOME");
-	    break;
-	  default:
-	    folder = NULL;
-	    break;
-	  }
-	  
-	  path_buf = (char*)malloc(strlen(fname)+2+((folder == NULL) ? 0 : strlen(folder)));
-	  
-	  if (folder == NULL)
-	    strcpy(path_buf,fname);
-	  else {
-	    strcpy(path_buf,folder);
-	    if (path_buf[strlen(path_buf)-1] != '/')
-	      strcat(path_buf, "/");
-	    strcat(path_buf,fname);
-	  }
-	  
-	  if (!access(path_buf, R_OK)) {
-	    // CPhipps - if extension is a standard deh/bex one, assume it's a patch
-	    // else assume it's a lump
-	    const char* ext = NULL;
-	    if (strlen(path_buf)>=4) ext = path_buf + strlen(path_buf) - 4;
-	    if (ext && (!strcasecmp(ext,".deh") || !strcasecmp(ext,".bex"))) 
-	      ProcessDehFile(path_buf, D_dehout(), 0);
-	    else {
-	      D_AddFile(path_buf,source_auto_load);
-	      modifiedgame = true; 
-	      i=99; // Exit loop
-	    }
-	  }
-	  free(path_buf);
-	}
+      fpath = FindWADFile(fname, ".wad");
+      if (!fpath)
+        lprintf(LO_WARN, "Failed to autoload %s\n", fname);
+      else {
+        /* CPhipps - if extension is a standard deh/bex one, assume it's a patch
+         * else assume it's a lump
+         */
+        const char* ext = NULL;
+        if (strlen(fpath)>=4) ext = fpath + strlen(fpath) - 4;
+        if (ext && (!strcasecmp(ext,".deh") || !strcasecmp(ext,".bex"))) 
+          ProcessDehFile(fpath, D_dehout(), 0);
+        else {
+          D_AddFile(fpath,source_auto_load);
+        }
+        modifiedgame = true; 
+        free(fpath);
       }
       free(fname);
     }
@@ -1886,6 +1737,21 @@ void GetFirstMap(int *ep, int *map)
 //----------------------------------------------------------------------------
 //
 // $Log: d_main.c,v $
+// Revision 1.46  2000/03/27 10:33:49  cph
+// Kludge for game start movement
+//
+// Revision 1.45  1999/12/18 15:17:22  cphipps
+// Completely cleaned up the WAD searching code
+// New function FindWADFile is used for IWAD and autoloading searches
+// FindIWADFile is now very simple, static buffers no longer needed
+// Removed redundant version printouts from IdentifyVersion
+//
+// Revision 1.44  1999/11/01 17:11:59  cphipps
+// Added i_main.h for I_Init
+//
+// Revision 1.43  1999/10/27 07:40:59  cphipps
+// Imported MBF tabularised demo sequence code
+//
 // Revision 1.42  1999/10/17 09:35:15  cphipps
 // Fixed hanging else(s)
 //
