@@ -1,7 +1,7 @@
 /* Emacs style mode select   -*- C++ -*- 
  *-----------------------------------------------------------------------------
  *
- * $Id: p_inter.c,v 1.8 1999/10/17 09:35:15 cphipps Exp $
+ * $Id: p_inter.c,v 1.9 1999/10/31 11:51:23 cphipps Exp $
  *
  *  LxDoom, a Doom port for Linux/Unix
  *  based on BOOM, a modified and improved DOOM engine
@@ -30,7 +30,7 @@
  *-----------------------------------------------------------------------------*/
 
 static const char
-rcsid[] = "$Id: p_inter.c,v 1.8 1999/10/17 09:35:15 cphipps Exp $";
+rcsid[] = "$Id: p_inter.c,v 1.9 1999/10/31 11:51:23 cphipps Exp $";
 
 #include "doomstat.h"
 #include "dstrings.h"
@@ -41,6 +41,7 @@ rcsid[] = "$Id: p_inter.c,v 1.8 1999/10/17 09:35:15 cphipps Exp $";
 #include "sounds.h"
 #include "d_deh.h"  // Ty 03/22/98 - externalized strings
 #include "p_tick.h"
+#include "lprintf.h"
 
 #ifdef __GNUG__
 #pragma implementation "p_inter.h"
@@ -813,8 +814,10 @@ void P_DamageMobj(mobj_t *target,mobj_t *inflictor, mobj_t *source, int damage)
 
       temp = damage < 100 ? damage : 100;
 
+#if 0
       if (player == &players[consoleplayer])
         I_Tactile (40,10,40+temp*2);
+#endif
     }
 
   // do the damage
@@ -858,6 +861,10 @@ void P_DamageMobj(mobj_t *target,mobj_t *inflictor, mobj_t *source, int damage)
 //----------------------------------------------------------------------------
 //
 // $Log: p_inter.c,v $
+// Revision 1.9  1999/10/31 11:51:23  cphipps
+// Comment out I_Tactile call (unused)
+// Include lprintf.h for I_Error
+//
 // Revision 1.8  1999/10/17 09:35:15  cphipps
 // Fixed hanging else(s)
 //
