@@ -1,7 +1,7 @@
 /* Emacs style mode select   -*- C++ -*- 
  *-----------------------------------------------------------------------------
  *
- * $Id: p_setup.c,v 1.13 1999/10/12 13:01:13 cphipps Exp $
+ * $Id: p_setup.c,v 1.14 1999/11/04 12:33:38 cphipps Exp $
  *
  *  LxDoom, a Doom port for Linux/Unix
  *  based on BOOM, a modified and improved DOOM engine
@@ -31,7 +31,7 @@
  *-----------------------------------------------------------------------------*/
 
 static const char
-rcsid[] = "$Id: p_setup.c,v 1.13 1999/10/12 13:01:13 cphipps Exp $";
+rcsid[] = "$Id: p_setup.c,v 1.14 1999/11/04 12:33:38 cphipps Exp $";
 
 #include <math.h>
 
@@ -161,29 +161,11 @@ static void P_LoadSegs (int lump)
 {
   int  i;
   const byte *data; // cph - const
-  byte *vertchanged = Z_Calloc(numvertexes,sizeof(byte),PU_LEVEL,0); // phares 10/4/98
-  line_t* line;     // phares 10/4/98
-  int ptp_angle;    // phares 10/4/98
-  int delta_angle;  // phares 10/4/98
-  int dis;          // phares 10/4/98
-  int dx,dy;        // phares 10/4/98
-  int vnum1,vnum2;  // phares 10/4/98
 
   numsegs = W_LumpLength(lump) / sizeof(mapseg_t);
   segs = Z_Calloc(numsegs,sizeof(seg_t),PU_LEVEL,0);
   data = W_CacheLumpNum(lump); // cph - wad lump handling updated
 
-  // phares: 10/4/98: Vertchanged is an array that represents the vertices.
-  // Mark those used by linedefs. A marked vertex is one that is not a
-  // candidate for movement further down.
-
-  line = lines;
-  for (i = 0; i < numlines ; i++,line++)
-    {
-    vertchanged[line->v1 - vertexes] = 1;
-    vertchanged[line->v2 - vertexes] = 1;
-    }
-
   for (i=0; i<numsegs; i++)
     {
       seg_t *li = segs+i;
@@ -196,64 +178,6 @@ static void P_LoadSegs (int lump)
       li->v2 = &vertexes[SHORT(ml->v2)];
 
       li->angle = (SHORT(ml->angle))<<16;
-
-// phares 10/4/98: In the case of a lineseg that was created by splitting
-// another line, it appears that the line angle is inherited from the
-// father line. Due to roundoff, the new vertex may have been placed 'off
-// the line'. When you get close to such a line, and it is very short,
-// it's possible that the roundoff error causes 'firelines', the thin
-// lines that can draw from screen top to screen bottom occasionally. This
-// is due to all the angle calculations that are done based on the line
-// angle, the angles from the viewer to the vertices, and the viewer's
-// angle in the world. In the case of firelines, the rounded-off position
-// of one of the vertices determines one of these angles, and introduces
-// an error in the scaling factor for mapping textures and determining
-// where on the screen the ceiling and floor spans should be shown. For a
-// fireline, the engine thinks the ceiling bottom and floor top are at the
-// midpoint of the screen. So you get ceilings drawn all the way down to the
-// screen midpoint, and floors drawn all the way up. Thus 'firelines'. The
-// name comes from the original sighting, which involved a fire texture.
-//
-// To correct this, reset the vertex that was added so that it sits ON the
-// split line.
-//
-// To know which of the two vertices was added, its number is greater than
-// that of the last of the author-created vertices. If both vertices of the
-// line were added by splitting, pick the higher-numbered one. Once you've
-// changed a vertex, don't change it again if it shows up in another seg.
-//
-// To determine if there's an error in the first place, find the
-// angle of the line between the two seg vertices. If it's one degree or more
-// off, then move one vertex. This may seem insignificant, but one degree
-// errors _can_ cause firelines.
-
-      ptp_angle = R_PointToAngle2(li->v1->x,li->v1->y,li->v2->x,li->v2->y);
-      dis = 0;
-      delta_angle = (abs(ptp_angle-li->angle)>>ANGLETOFINESHIFT)*360/8192;
-
-      if (delta_angle != 0)
-        {
-        dx = (li->v1->x - li->v2->x)>>FRACBITS;
-        dy = (li->v1->y - li->v2->y)>>FRACBITS;
-        dis = ((int) sqrt(dx*dx + dy*dy))<<FRACBITS;
-        dx = finecosine[li->angle>>ANGLETOFINESHIFT];
-        dy = finesine[li->angle>>ANGLETOFINESHIFT];
-        vnum1 = li->v1 - vertexes; 
-        vnum2 = li->v2 - vertexes; 
-        if ((vnum2 > vnum1) && (vertchanged[vnum2] == 0))
-          {
-          li->v2->x = li->v1->x + FixedMul(dis,dx);
-          li->v2->y = li->v1->y + FixedMul(dis,dy);
-          vertchanged[vnum2] = 1; // this was changed
-          }
-        else if (vertchanged[vnum1] == 0)
-          {
-          li->v1->x = li->v2->x - FixedMul(dis,dx);
-          li->v1->y = li->v2->y - FixedMul(dis,dy);
-          vertchanged[vnum1] = 1; // this was changed
-          }
-        }
-
       li->offset = (SHORT(ml->offset))<<16;
       linedef = SHORT(ml->linedef);
       ldef = &lines[linedef];
@@ -270,7 +194,6 @@ static void P_LoadSegs (int lump)
     }
 
   W_UnlockLumpNum(lump); // cph - release the data
-  Z_Free(vertchanged); // phares 10/4/98
 }
 
 
@@ -936,110 +859,6 @@ void P_CreateBlockMap()
 // jff 10/6/98
 // End new code added to speed up calculation of internal blockmap
 
-#if 0   /*jff 10/6/98 this code superseded by faster blockmap routine above */
-
-// killough 5/3/98: tests whether a linedef is inside a block.
-static boolean IsLineDefInside(const line_t *l, int x, int y)
-{
-  int dx = l->dx >> FRACBITS;
-  int dy = l->dy >> FRACBITS;
-  int a = (l->v1->x >> FRACBITS) - x;
-  int b = (l->v1->y >> FRACBITS) - y;
-
-  if (abs(a*2+dx)-abs(dx) > MAPBLOCKUNITS ||
-      abs(b*2+dy)-abs(dy) > MAPBLOCKUNITS )
-    return 0;
-
-  a *= dy;
-  b *= dx;
-  a -= b;
-  b = dx + dy;
-  b <<= MAPBTOFRAC-1;
-  if (((a-b)^(a+b)) < 0)
-    return 1;
-  dy -= dx;
-  dy <<= MAPBTOFRAC-1;
-  b = a+dy;
-  a -= dy;
-  return (a^b) < 0;
-}
-
-static void P_CreateBlockMap(void)
-{
-  long minx = LONG_MAX, miny = LONG_MAX, maxx = LONG_MIN, maxy = LONG_MIN;
-  long i, tot, *bmap, nalloc, bx, by, count;
-
-  // First find limits of map
-
-  for (i=0; i<numlines; i++)
-    {
-      vertex_t *v;
-      fixed_t t;
-      v = lines[i].v1;
-      t = v->x >> FRACBITS;
-      if (t < minx)
-        minx = t;
-      else
-        if (t > maxx)
-          maxx = t;
-      t = v->y >> FRACBITS;
-      if (t < miny)
-        miny = t;
-      else
-        if (t > maxy)
-          maxy = t;
-      v = lines[i].v2;
-      t = v->x >> FRACBITS;
-      if (t < minx)
-        minx = t;
-      else
-        if (t > maxx)
-          maxx = t;
-      t = v->y >> FRACBITS;
-      if (t < miny)
-        miny = t;
-      else
-        if (t > maxy)
-          maxy = t;
-    }
-
-  bmaporgx = minx << FRACBITS;
-  bmaporgy = miny << FRACBITS;
-  bmapwidth  = ((maxx-minx) >> MAPBTOFRAC) + 1;
-  bmapheight = ((maxy-miny) >> MAPBTOFRAC) + 1;
-  count = tot = bmapwidth * bmapheight + 4;
-  nalloc = tot + numlines*2 + 2;
-  bmap = malloc(sizeof(*bmap) * nalloc);
-
-  // Brute-force algorithm for now -- a better way would be a Bresenham-like
-  // traversal of the linedef, through the blocks it touches, moving either
-  // horizontally or vertically one block at each step. killough 3/30/98
-
-  minx += MAPBLOCKUNITS/2;
-  miny += MAPBLOCKUNITS/2;
-  for (i=4, by=0; by<bmapheight; by++, miny += MAPBLOCKUNITS)
-    {
-      long x = minx;
-      for (bx=0; bx<bmapwidth; bx++, i++, x += MAPBLOCKUNITS)
-        {
-          int j;
-          bmap[i] = count;
-          if (count+numlines+2 >= nalloc)
-            bmap = realloc(bmap, sizeof(*bmap) * (nalloc*=2));
-          bmap[count++] = 0;
-          for (j=0; j<numlines; j++)
-            if (IsLineDefInside(lines+j, x, miny))
-              bmap[count++] = j;
-          bmap[count++] = -1;
-        }
-    }
-  blockmaplump = Z_Malloc(sizeof(*blockmaplump) * count, PU_LEVEL, 0);
-  memcpy(blockmaplump, bmap, count * sizeof(*bmap));
-  free(bmap);
-}
-
-#endif
-
 //
 // P_LoadBlockMap
 //
@@ -1178,6 +997,82 @@ void P_GroupLines (void)
   }
 }
 
+//
+// killough 10/98
+//
+// Remove slime trails.
+//
+// Slime trails are inherent to Doom's coordinate system -- i.e. there is
+// nothing that a node builder can do to prevent slime trails ALL of the time,
+// because it's a product of the integer coodinate system, and just because
+// two lines pass through exact integer coordinates, doesn't necessarily mean
+// that they will intersect at integer coordinates. Thus we must allow for
+// fractional coordinates if we are to be able to split segs with node lines,
+// as a node builder must do when creating a BSP tree.
+//
+// A wad file does not allow fractional coordinates, so node builders are out
+// of luck except that they can try to limit the number of splits (they might
+// also be able to detect the degree of roundoff error and try to avoid splits
+// with a high degree of roundoff error). But we can use fractional coordinates
+// here, inside the engine. It's like the difference between square inches and
+// square miles, in terms of granularity.
+//
+// For each vertex of every seg, check to see whether it's also a vertex of
+// the linedef associated with the seg (i.e, it's an endpoint). If it's not
+// an endpoint, and it wasn't already moved, move the vertex towards the
+// linedef by projecting it using the law of cosines. Formula:
+//
+//      2        2                         2        2
+//    dx  x0 + dy  x1 + dx dy (y0 - y1)  dy  y0 + dx  y1 + dx dy (x0 - x1)
+//   {---------------------------------, ---------------------------------}
+//                  2     2                            2     2
+//                dx  + dy                           dx  + dy
+//
+// (x0,y0) is the vertex being moved, and (x1,y1)-(x1+dx,y1+dy) is the
+// reference linedef.
+//
+// Segs corresponding to orthogonal linedefs (exactly vertical or horizontal
+// linedefs), which comprise at least half of all linedefs in most wads, don't
+// need to be considered, because they almost never contribute to slime trails
+// (because then any roundoff error is parallel to the linedef, which doesn't
+// cause slime). Skipping simple orthogonal lines lets the code finish quicker.
+//
+// Please note: This section of code is not interchangable with TeamTNT's
+// code which attempts to fix the same problem.
+//
+// Firelines (TM) is a Rezistered Trademark of MBF Productions
+//
+
+void P_RemoveSlimeTrails(void)                // killough 10/98
+{
+  byte *hit = calloc(1, numvertexes);         // Hitlist for vertices
+  int i;
+  for (i=0; i<numsegs; i++)                   // Go through each seg
+    {
+      const line_t *l = segs[i].linedef;      // The parent linedef
+      if (l->dx && l->dy)                     // We can ignore orthogonal lines
+	{
+	  vertex_t *v = segs[i].v1;
+	  do
+	    if (!hit[v - vertexes])           // If we haven't processed vertex
+	      {
+		hit[v - vertexes] = 1;        // Mark this vertex as processed
+		if (v != l->v1 && v != l->v2) // Exclude endpoints of linedefs
+		  { // Project the vertex back onto the parent linedef
+		    long long dx2 = (l->dx >> FRACBITS) * (l->dx >> FRACBITS);
+		    long long dy2 = (l->dy >> FRACBITS) * (l->dy >> FRACBITS);
+		    long long dxy = (l->dx >> FRACBITS) * (l->dy >> FRACBITS);
+		    long long s = dx2 + dy2;
+		    int x0 = v->x, y0 = v->y, x1 = l->v1->x, y1 = l->v1->y;
+		    v->x = (dx2 * x0 + dy2 * x1 + dxy * (y0 - y1)) / s;
+		    v->y = (dy2 * y0 + dx2 * y1 + dxy * (x0 - x1)) / s;
+		  }
+	      }  // Obsfucated C contest entry:   :)
+	  while ((v != segs[i].v2) && (v = segs[i].v2));
+	}
+    }
+  free(hit);
+}
 
 //
 // P_SetupLevel
@@ -1244,6 +1139,8 @@ void P_SetupLevel(int episode, int map, int playermask, skill_t skill)
   rejectmatrix = W_CacheLumpNum(rejectlump = lumpnum+ML_REJECT);
   P_GroupLines();
 
+  P_RemoveSlimeTrails();    // killough 10/98: remove slime trails from wad      
+                                                                                    
   bodyqueslot = 0;
 
 // phares 8/10/98: Clear body queue so the corpses from previous games are
@@ -1294,6 +1191,9 @@ void P_Init (void)
 //----------------------------------------------------------------------------
 //
 // $Log: p_setup.c,v $
+// Revision 1.14  1999/11/04 12:33:38  cphipps
+// Switch from the Boom fireline-recuding code to the MBF fireline code.
+//
 // Revision 1.13  1999/10/12 13:01:13  cphipps
 // Changed header to GPL
 //
