@@ -1,7 +1,7 @@
 /* Emacs style mode select   -*- C++ -*- 
  *-----------------------------------------------------------------------------
  *
- * $Id: r_data.c,v 1.11 1999/10/12 13:01:14 cphipps Exp $
+ * $Id: r_data.c,v 1.13 2000/01/25 22:40:45 cphipps Exp $
  *
  *  LxDoom, a Doom port for Linux/Unix
  *  based on BOOM, a modified and improved DOOM engine
@@ -31,7 +31,7 @@
  *-----------------------------------------------------------------------------*/
 
 static const char
-rcsid[] = "$Id: r_data.c,v 1.11 1999/10/12 13:01:14 cphipps Exp $";
+rcsid[] = "$Id: r_data.c,v 1.13 2000/01/25 22:40:45 cphipps Exp $";
 
 #include "doomstat.h"
 #include "w_wad.h"
@@ -519,14 +519,19 @@ void R_InitTextures (void)
       texture->height = SHORT(mtexture->height);
       texture->patchcount = SHORT(mtexture->patchcount);
 
-#ifndef SPARC
-      /* cph - I find it hard to believe that sparc memcpy is broken, 
+#if 1
+      /* The above was #ifndef SPARC, but i got a mail from
+       * Putera Joseph F NPRI <PuteraJF@Npt.NUWC.Navy.Mil> containing:
+       *   I had to use the memcpy function on a sparc machine.  The
+       *   other one would give me a core dump.
+       * cph - I find it hard to believe that sparc memcpy is broken, 
        * but I don't believe the pointers to memcpy have to be aligned 
        * either. Use fast memcpy on other machines anyway.
        */
       memcpy(texture->name, mtexture->name, sizeof(texture->name));
 #else
       /* memcpy seems to assume that its params are aligned on sparc - josh */
+      /* cph - how this can core dump is beyond me */
       { 
 	 int j; 
 	 for(j=0;j<sizeof(texture->name);j++) 
@@ -630,7 +635,7 @@ void R_InitFlats(void)
 void R_InitSpriteLumps(void)
 {
   int i;
-  patch_t *patch;
+  const patch_t *patch;
 
   firstspritelump = W_GetNumForName("S_START") + 1;
   lastspritelump = W_GetNumForName("S_END") - 1;
@@ -984,6 +989,12 @@ void R_PrecacheLevel(void)
 //-----------------------------------------------------------------------------
 //
 // $Log: r_data.c,v $
+// Revision 1.13  2000/01/25 22:40:45  cphipps
+// Revert SPARC memcpy patch
+//
+// Revision 1.12  1999/10/27 18:38:14  cphipps
+// Made W_CacheLump* return a const pointer
+//
 // Revision 1.11  1999/10/12 13:01:14  cphipps
 // Changed header to GPL
 //
