@@ -1,7 +1,7 @@
 /* Emacs style mode select   -*- C++ -*- 
  *-----------------------------------------------------------------------------
  *
- * $Id: r_main.c,v 1.19 1999/10/12 13:01:14 cphipps Exp $
+ * $Id: r_main.c,v 1.20 1999/10/31 15:51:45 cphipps Exp $
  *
  *  LxDoom, a Doom port for Linux/Unix
  *  based on BOOM, a modified and improved DOOM engine
@@ -31,7 +31,7 @@
  *
  *-----------------------------------------------------------------------------*/
 
-static const char rcsid[] = "$Id: r_main.c,v 1.19 1999/10/12 13:01:14 cphipps Exp $";
+static const char rcsid[] = "$Id: r_main.c,v 1.20 1999/10/31 15:51:45 cphipps Exp $";
 
 #include "doomstat.h"
 #include "w_wad.h"
@@ -45,6 +45,7 @@ static const char rcsid[] = "$Id: r_main.c,v 1.19 1999/10/12 13:01:14 cphipps Ex
 #include "v_video.h"
 #include "lprintf.h"
 #include "st_stuff.h"
+#include "i_main.h"
 
 void R_LoadTrigTables(void);
 
@@ -686,6 +687,9 @@ void R_RenderPlayerView (player_t* player)
 //----------------------------------------------------------------------------
 //
 // $Log: r_main.c,v $
+// Revision 1.20  1999/10/31 15:51:45  cphipps
+// Added i_main.h include for time function
+//
 // Revision 1.19  1999/10/12 13:01:14  cphipps
 // Changed header to GPL
 //
