@@ -1,7 +1,7 @@
 /* Emacs style mode select   -*- C++ -*- 
  *-----------------------------------------------------------------------------
  *
- * $Id: r_things.c,v 1.10 1999/10/17 09:35:14 cphipps Exp $
+ * $Id: r_things.c,v 1.11 1999/11/01 17:09:14 cphipps Exp $
  *
  *  LxDoom, a Doom port for Linux/Unix
  *  based on BOOM, a modified and improved DOOM engine
@@ -30,7 +30,7 @@
  *-----------------------------------------------------------------------------*/
 
 static const char
-rcsid[] = "$Id: r_things.c,v 1.10 1999/10/17 09:35:14 cphipps Exp $";
+rcsid[] = "$Id: r_things.c,v 1.11 1999/11/01 17:09:14 cphipps Exp $";
 
 #include "doomstat.h"
 #include "w_wad.h"
@@ -39,6 +39,7 @@ rcsid[] = "$Id: r_things.c,v 1.10 1999/10/17 09:35:14 cphipps Exp $";
 #include "r_segs.h"
 #include "r_draw.h"
 #include "r_things.h"
+#include "lprintf.h"
 
 #define MINZ        (FRACUNIT*4)
 #define BASEYCENTER 100
@@ -984,6 +985,9 @@ void R_DrawMasked(void)
 //----------------------------------------------------------------------------
 //
 // $Log: r_things.c,v $
+// Revision 1.11  1999/11/01 17:09:14  cphipps
+// Added lprintf.h (needed for RANGECHECK debugging I_Error calls)
+//
 // Revision 1.10  1999/10/17 09:35:14  cphipps
 // Fixed hanging else(s)
 //
