@@ -1,7 +1,7 @@
 /* Emacs style mode select   -*- C++ -*- 
  *-----------------------------------------------------------------------------
  *
- * $Id: v_video.c,v 1.16 1999/10/12 13:01:15 cphipps Exp $
+ * $Id: v_video.c,v 1.18 1999/10/27 18:38:03 cphipps Exp $
  *
  *  LxDoom, a Doom port for Linux/Unix
  *  based on BOOM, a modified and improved DOOM engine
@@ -34,7 +34,7 @@
  */
 
 static const char
-rcsid[] = "$Id: v_video.c,v 1.16 1999/10/12 13:01:15 cphipps Exp $";
+rcsid[] = "$Id: v_video.c,v 1.18 1999/10/27 18:38:03 cphipps Exp $";
 
 #include "doomdef.h"
 #include "r_main.h"
@@ -47,23 +47,25 @@ rcsid[] = "$Id: v_video.c,v 1.16 1999/10/12 13:01:15 cphipps Exp $";
 byte *screens[6];
 int  dirtybox[4];
 
-//jff 2/18/98 palette color ranges for translation
-//jff 4/24/98 now pointers set to predefined lumps to allow overloading
+/* jff 2/18/98 palette color ranges for translation
+ * jff 4/24/98 now pointers set to predefined lumps to allow overloading
+ * cphipps 10/99 - be consistent in using byte for pixel values
+ */
 
-char *cr_brick;
-char *cr_tan;
-char *cr_gray;
-char *cr_green;
-char *cr_brown;
-char *cr_gold;
-char *cr_red;
-char *cr_blue;
-char *cr_blue_status;
-char *cr_orange;
-char *cr_yellow;
+const byte *cr_brick;
+const byte *cr_tan;
+const byte *cr_gray;
+const byte *cr_green;
+const byte *cr_brown;
+const byte *cr_gold;
+const byte *cr_red;
+const byte *cr_blue;
+const byte *cr_blue_status;
+const byte *cr_orange;
+const byte *cr_yellow;
 
 //jff 4/24/98 initialize this at runtime
-char *colrngs[10];
+const byte *colrngs[10];
 
 // Now where did these came from?
 const byte gammatable[5][256] = // CPhipps - const
@@ -152,22 +154,24 @@ const byte gammatable[5][256] = // CPhipps - const
 
 int usegamma;
 
-//
-// V_InitColorTranslation
-//
-// Loads the color translation tables from predefined lumps at game start
-// No return
-//
-// Used for translating text colors from the red palette range
-// to other colors. The first nine entries can be used to dynamically
-// switch the output of text color thru the HUlib_drawText routine
-// by embedding ESCn in the text to obtain color n. Symbols for n are
-// provided in v_video.h.
-//
+/*
+ * V_InitColorTranslation
+ *
+ * Loads the color translation tables from predefined lumps at game start
+ * No return
+ *
+ * Used for translating text colors from the red palette range
+ * to other colors. The first nine entries can be used to dynamically
+ * switch the output of text color thru the HUlib_drawText routine
+ * by embedding ESCn in the text to obtain color n. Symbols for n are
+ * provided in v_video.h.
+ *
+ * cphipps - constness of crdef_t stuff fixed
+ */
 
 typedef struct {
   const char *name;
-  char **map1, **map2;
+  const byte **map1, **map2;
 } crdef_t;
 
 // killough 5/2/98: table-driven approach
@@ -315,6 +319,32 @@ void V_DrawBlock(int x, int y, int scrn, int width, int height,
   }
 }
 
+/*
+ * V_DrawBackground tiles a 64x64 patch over the entire screen, providing the
+ * background for the Help and Setup screens, and plot text betwen levels.
+ * cphipps - used to have M_DrawBackground, but that was used the framebuffer 
+ * directly, so this is my code from the equivalent function in f_finale.c
+ */
+
+void V_DrawBackground(const char* flatname)
+{
+  /* erase the entire screen to a tiled background */
+  const byte *src;
+  int         x,y;
+  int         lump;
+  
+  // killough 4/17/98: 
+  src = W_CacheLumpNum(lump = firstflat + R_FlatNumForName(flatname));
+  
+  V_DrawBlock(0, 0, 0, 64, 64, src, 0);
+  
+  for (y=0 ; y<SCREENHEIGHT ; y+=64)
+    for (x=y ? 0 : 64; x<SCREENWIDTH ; x+=64)
+      V_CopyRect(0, 0, 0, ((SCREENWIDTH-x) < 64) ? (SCREENWIDTH-x) : 64, 
+		 ((SCREENHEIGHT-y) < 64) ? (SCREENHEIGHT-y) : 64, x, y, 0);
+  W_UnlockLumpNum(lump);
+}
+
 //
 // V_GetBlock
 //
@@ -383,7 +413,7 @@ void V_Init (void)
 //  means that their inner loops weren't so well optimised, so merging code may even speed them).
 //
 void V_DrawMemPatch(int x, int y, int scrn, const patch_t *patch, 
-		    const unsigned char *trans, enum patch_translation_e flags)
+		    const byte *trans, enum patch_translation_e flags)
 {
   y -= SHORT(patch->topoffset);
   x -= SHORT(patch->leftoffset);
@@ -552,7 +582,7 @@ void V_DrawMemPatch(int x, int y, int scrn, const patch_t *patch,
 inline
 #endif
 void V_DrawNumPatch(int x, int y, int scrn, int lump, 
-			   const unsigned char *trans, enum patch_translation_e flags)
+			   const byte *trans, enum patch_translation_e flags)
 {
   V_DrawMemPatch(x, y, scrn, (const patch_t*)W_CacheLumpNum(lump), 
 		 trans, flags);
@@ -560,7 +590,7 @@ void V_DrawNumPatch(int x, int y, int scrn, int lump,
 }
 
 void V_DrawNamePatch(int x, int y, int scrn, const char *name, 
-		     const unsigned char *trans, enum patch_translation_e flags)
+		     const byte *trans, enum patch_translation_e flags)
 {
   V_DrawNumPatch(x, y, scrn, W_GetNumForName(name), trans, flags);
 }
@@ -571,7 +601,7 @@ void V_DrawNamePatch(int x, int y, int scrn, const char *name,
 // Returns a simple bitmap which contains the patch. See-through parts of the 
 // patch will be undefined (in fact black for now)
 
-unsigned char *V_PatchToBlock(const char* name, const unsigned char *trans, 
+byte *V_PatchToBlock(const char* name, const byte *trans, 
 			      enum patch_translation_e flags, 
 			      unsigned short* width, unsigned short* height)
 {
@@ -630,6 +660,15 @@ void V_FillRect(int scrn, int x, int y, int width, int height, byte colour)
 //----------------------------------------------------------------------------
 //
 // $Log: v_video.c,v $
+// Revision 1.18  1999/10/27 18:38:03  cphipps
+// Updated for W_Cache'd lumps being properly const
+// Made colour translation tables be referenced by const byte*'s
+// Updated various V_* functions for this change
+//
+// Revision 1.17  1999/10/27 11:59:49  cphipps
+// Added V_DrawBackground, which draws a tiled flat over the screen
+// (taken from M_DrawBackground and similar code in f_finale.c)
+//
 // Revision 1.16  1999/10/12 13:01:15  cphipps
 // Changed header to GPL
 //
