@@ -1,7 +1,7 @@
 /* Emacs style mode select   -*- C++ -*- 
  *-----------------------------------------------------------------------------
  *
- * $Id: z_zone.c,v 1.9 1999/10/12 13:01:15 cphipps Exp $
+ * $Id: z_zone.c,v 1.10 1999/10/31 12:49:44 cphipps Exp $
  *
  *  LxDoom, a Doom port for Linux/Unix
  *  based on BOOM, a modified and improved DOOM engine
@@ -38,7 +38,7 @@
  *-----------------------------------------------------------------------------
  */
 
-static const char rcsid[] = "$Id: z_zone.c,v 1.9 1999/10/12 13:01:15 cphipps Exp $";
+static const char rcsid[] = "$Id: z_zone.c,v 1.10 1999/10/31 12:49:44 cphipps Exp $";
 
 // use config.h if autoconf made one -- josh
 #ifdef HAVE_CONFIG_H
@@ -51,6 +51,7 @@ static const char rcsid[] = "$Id: z_zone.c,v 1.9 1999/10/12 13:01:15 cphipps Exp
 #include "z_zone.h"
 #include "doomstat.h"
 #include "m_argv.h"
+#include "lprintf.h"
 
 #ifdef DJGPP
 #include <dpmi.h>
@@ -661,6 +662,9 @@ void (Z_CheckHeap)(const char *file, int line)
 //-----------------------------------------------------------------------------
 //
 // $Log: z_zone.c,v $
+// Revision 1.10  1999/10/31 12:49:44  cphipps
+// Use lprintf.h for I_Error
+//
 // Revision 1.9  1999/10/12 13:01:15  cphipps
 // Changed header to GPL
 //
